"use client";
import Link from "next/link";
import Image from "next/image";
import logoImg from "@/assets/images/brand/logo.svg";
import { motion } from "motion/react";

export default function Delegate() {
  return (
    <div className="p-2.5 h-[100svh]">
      <main className="h-full grid grid-cols-[450px_auto]">
        <div className="relative p-10 flex flex-col justify-between">
          <div className="relative z-10">
            <motion.div
              initial={{ y: -25, opacity: 0 }}
              whileInView={{ y: 0, opacity: 1 }}
              viewport={{ once: true }}
              transition={{ duration: 0.25 }}
            >
              <Link href={"/"} className="mb-20 flex items-center gap-2.5">
                <Image src={logoImg} alt="" width={180} />

                <p className="px-1.5 bg-[#09C04C] rounded-lg font-mono font-medium uppercase text-[#193818]">
                  Beta
                </p>
              </Link>
            </motion.div>

            <motion.p
              initial={{ y: -25, opacity: 0 }}
              whileInView={{ y: 0, opacity: 1 }}
              viewport={{ once: true }}
              transition={{ duration: 0.25, delay: 0.1 }}
              className="font-mono text-sm font-medium uppercase text-[#09C04C]"
            >
              Get Started
            </motion.p>

            <motion.h1
              initial={{ y: -25, opacity: 0 }}
              whileInView={{ y: 0, opacity: 1 }}
              viewport={{ once: true }}
              transition={{ duration: 0.25, delay: 0.2 }}
              className="mt-1.5 mb-2.5 font-serif text-5xl font-bold text-white"
            >
              Welcome
            </motion.h1>

            <motion.p
              initial={{ y: -25, opacity: 0 }}
              whileInView={{ y: 0, opacity: 1 }}
              viewport={{ once: true }}
              transition={{ duration: 0.25, delay: 0.3 }}
              className="text-white/75"
            >
              Collano is your intelligent companion for the BNB Smart Chain
              ecosystem, revolutionizing how users interact with blockchain
              technology through natural language understanding and automated
              assistance.
            </motion.p>
          </div>

          <div className="relative z-10 w-full flex justify-between items-center">
            <motion.div
              initial={{ y: -25, opacity: 0 }}
              whileInView={{ y: 0, opacity: 1 }}
              viewport={{ once: true }}
              transition={{ duration: 0.25, delay: 0.4 }}
              className="flex gap-5"
            >
              <Link
                href={"/legal/tos"}
                className="text-white/75 hover:text-[#d1ca0d] duration-200"
              >
                Terms
              </Link>

              <Link
                href={"/legal/privacy-policy"}
                className="text-white/75 hover:text-[#d1ca0d] duration-200"
              >
                Privacy
              </Link>

              <Link
                href={"/"}
                className="text-white/75 hover:text-[#d1ca0d] duration-200"
              >
                Docs
              </Link>
            </motion.div>

            <motion.div
              initial={{ y: -25, opacity: 0 }}
              whileInView={{ y: 0, opacity: 1 }}
              viewport={{ once: true }}
              transition={{ duration: 0.25, delay: 0.5 }}
              className="flex items-center gap-4"
            >
              <Link href={"/"} className="group flex">
                <svg
                  width="20"
                  height="20"
                  viewBox="0 0 20 20"
                  fill="none"
                  xmlns="http://www.w3.org/2000/svg"
                >
                  <path
                    d="M15.2719 1.58661H18.0831L11.9414 8.60619L19.1666 18.1582H13.5093L9.07834 12.365L4.00827 18.1582H1.19534L7.76451 10.65L0.833313 1.58661H6.63424L10.6395 6.88189L15.2719 1.58661ZM14.2852 16.4756H15.843L5.78781 3.18089H4.1162L14.2852 16.4756Z"
                    fill="white"
                    className="group-hover:fill-[#d1ca0d] duration-200"
                  />
                </svg>
              </Link>

              <Link href={"/"} className="group flex">
                <svg
                  width="20"
                  height="20"
                  viewBox="0 0 20 20"
                  fill="none"
                  xmlns="http://www.w3.org/2000/svg"
                >
                  <path
                    d="M8.42967 10.5292C9.39247 11.0849 9.87385 11.3627 10.4026 11.3632C10.9312 11.3636 11.4131 11.0866 12.3769 10.5326L18.5204 7.00114C18.7978 6.84173 18.9687 6.54622 18.9687 6.22631C18.9687 5.9064 18.7978 5.6109 18.5204 5.45148L12.3747 1.91871C11.4119 1.3653 10.9306 1.0886 10.4024 1.08881C9.87422 1.08901 9.39308 1.36609 8.43078 1.92025L3.14748 4.96274C3.10831 4.9853 3.08875 4.99656 3.07049 5.00723C1.26576 6.06373 0.150741 7.99253 0.135832 10.0837C0.135681 10.1048 0.135681 10.1274 0.135681 10.1726C0.135681 10.2178 0.135681 10.2403 0.135832 10.2614C0.150708 12.3502 1.26324 14.2772 3.06475 15.3346C3.08296 15.3453 3.1025 15.3565 3.14161 15.3791L6.45105 17.2899C8.37945 18.4033 9.34364 18.96 10.4025 18.9603C11.4613 18.9607 12.4259 18.4046 14.3551 17.2926L17.8486 15.2786C18.8146 14.7217 19.2976 14.4433 19.5628 13.9843C19.828 13.5253 19.828 12.9678 19.828 11.8528V9.69893C19.828 9.3896 19.6605 9.10456 19.3902 8.95403C19.1287 8.8084 18.81 8.81056 18.5505 8.95973L11.3869 13.0776C10.9063 13.3539 10.6659 13.492 10.4022 13.4921C10.1385 13.4922 9.89813 13.3542 9.41733 13.0782L4.56884 10.295C4.32598 10.1556 4.20453 10.0859 4.10699 10.0733C3.88462 10.0446 3.67081 10.1692 3.5861 10.3768C3.54896 10.4679 3.5497 10.6079 3.55121 10.8879C3.55231 11.0941 3.55287 11.1972 3.57213 11.292C3.6153 11.5043 3.72699 11.6966 3.8901 11.8392C3.96293 11.9029 4.05219 11.9544 4.23075 12.0575L9.41459 15.0494C9.89665 15.3276 10.1377 15.4667 10.4023 15.4668C10.667 15.4669 10.9081 15.3279 11.3903 15.0499L17.7441 11.3873C17.9088 11.2924 17.9912 11.2449 18.053 11.2806C18.1147 11.3163 18.1147 11.4113 18.1147 11.6014V12.5784C18.1147 12.8572 18.1147 12.9965 18.0484 13.1113C17.9821 13.226 17.8613 13.2957 17.6198 13.4349L12.3791 16.4558C11.4143 17.0119 10.9319 17.29 10.4024 17.2898C9.8729 17.2895 9.39074 17.011 8.42647 16.454L3.52336 13.6217C3.50779 13.6126 3.50001 13.6082 3.49275 13.6039C2.46469 13.0032 1.83034 11.9042 1.82439 10.7134C1.82435 10.705 1.82435 10.6961 1.82435 10.6781V9.78126C1.82435 9.12394 2.17443 8.5164 2.74312 8.18677C3.24564 7.89548 3.86548 7.8949 4.36853 8.18526L8.42967 10.5292Z"
                    fill="white"
                    className="group-hover:fill-[#d1ca0d] duration-200"
                  />
                </svg>
              </Link>
            </motion.div>
          </div>

          <Image
            src={"/images/sidebar-icon.png"}
            alt=""
            width={550}
            height={550}
            className="absolute bottom-20 -right-20 opacity-20"
          />
        </div>

        <div
          className="relative z-10 pt-[200px] bg-[#121A15] rounded-xl flex justify-center"
          style={{
            backgroundImage: `url("/images/body-bg.png")`,
            backgroundSize: "cover",
            backgroundPosition: "center",
          }}
        >
          <div className="w-full max-w-[780px] space-y-7">
            <div className="w-full max-w-[550px]">
              <motion.p
                initial={{ y: -25, opacity: 0 }}
                whileInView={{ y: 0, opacity: 1 }}
                viewport={{ once: true }}
                transition={{ duration: 0.25, delay: 0.1 }}
                className="font-mono text-sm font-medium uppercase text-[#09C04C]"
              >
                Delegate
              </motion.p>

              <motion.h3
                initial={{ y: -25, opacity: 0 }}
                whileInView={{ y: 0, opacity: 1 }}
                viewport={{ once: true }}
                transition={{ duration: 0.25, delay: 0.2 }}
                className="mt-1.5 mb-2.5 font-serif text-3xl font-bold text-white"
              >
                Delegate your wallet
              </motion.h3>

              <motion.div
                initial={{ y: -25, opacity: 0 }}
                whileInView={{ y: 0, opacity: 1 }}
                viewport={{ once: true }}
                transition={{ duration: 0.25, delay: 0.4 }}
                className="mb-5 w-full p-3 border border-white/25 bg-white/10 rounded-lg flex items-center gap-3"
              >
                <svg
                  width="27"
                  height="22"
                  viewBox="0 0 27 22"
                  fill="none"
                  xmlns="http://www.w3.org/2000/svg"
                >
                  <path
                    d="M7.25 14.75V7.25"
                    stroke="white"
                    strokeWidth="1.875"
                    strokeLinecap="round"
                    strokeLinejoin="round"
                  />
                  <path
                    d="M24.5416 7.25H21.2885C19.0581 7.25 17.25 8.92887 17.25 11C17.25 13.0711 19.0581 14.75 21.2885 14.75H24.5416C24.6459 14.75 24.6979 14.75 24.7419 14.7474C25.416 14.7063 25.9529 14.2078 25.9971 13.5818C26 13.5409 26 13.4925 26 13.3959V8.60412C26 8.5075 26 8.45907 25.9971 8.41825C25.9529 7.7923 25.416 7.2937 24.7419 7.25268C24.6979 7.25 24.6459 7.25 24.5416 7.25Z"
                    stroke="white"
                    strokeWidth="1.875"
                  />
                  <path
                    d="M24.7062 7.25C24.6091 4.90962 24.2957 3.47469 23.2855 2.46446C21.8211 1 19.464 1 14.75 1H11C6.28595 1 3.92894 1 2.46446 2.46446C1 3.92894 1 6.28595 1 11C1 15.714 1 18.0711 2.46446 19.5355C3.92894 21 6.28595 21 11 21H14.75C19.464 21 21.8211 21 23.2855 19.5355C24.2957 18.5254 24.6091 17.0904 24.7062 14.75"
                    stroke="white"
                    strokeWidth="1.875"
                  />
                  <path
                    d="M20.9888 11H21.0003"
                    stroke="white"
                    strokeWidth="2.5"
                    strokeLinecap="round"
                    strokeLinejoin="round"
                  />
                </svg>

                <p className="font-medium text-white">
                  0x625EF1A576fAF469A0685871FAB46B9bE158ed49
                </p>
              </motion.div>

              <motion.p
                initial={{ y: -25, opacity: 0 }}
                whileInView={{ y: 0, opacity: 1 }}
                viewport={{ once: true }}
                transition={{ duration: 0.25, delay: 0.6 }}
                className="mb-5 text-white/75"
              >
                After delegating your wallet, you would be able to access
                Collano Labs AI, BNB CoPilot Program
              </motion.p>

              <motion.div
                initial={{ y: -25, opacity: 0 }}
                whileInView={{ y: 0, opacity: 1 }}
                viewport={{ once: true }}
                transition={{ duration: 0.25, delay: 0.8 }}
              >
                <Link
                  href={"/dashboard/home"}
                  className="btn-bg w-fit py-2.5 px-10 rounded-lg flex items-center gap-4 font-dm text-lg font-semibold text-white duration-200"
                >
                  <svg
                    width="24"
                    height="25"
                    viewBox="0 0 24 25"
                    fill="none"
                    xmlns="http://www.w3.org/2000/svg"
                  >
                    <path
                      d="M22 12.5C22 6.97715 17.5228 2.5 12 2.5C6.47715 2.5 2 6.97715 2 12.5C2 18.0228 6.47715 22.5 12 22.5C17.5228 22.5 22 18.0228 22 12.5Z"
                      stroke="white"
                      strokeWidth="1.5"
                    />
                    <path
                      d="M8 13L10.5 15.5L16 9.5"
                      stroke="white"
                      strokeWidth="1.5"
                      strokeLinecap="round"
                      strokeLinejoin="round"
                    />
                  </svg>
                  <span className="w-px h-[25px] bg-white block"></span>
                  Delegate
                </Link>
              </motion.div>
            </div>
          </div>
        </div>
      </main>

      <div className="absolute -z-10 -top-1/3 -left-[180px] w-[750px] h-[750px] bg-[#6B6700] blur-[150px] rounded-full"></div>
    </div>
  );
}
