import type { Metadata } from "next";
import {
  DM_Sans,
  Geist,
  Geist_Mono,
  Plus_Jakarta_Sans,
} from "next/font/google";
import "./globals.css";
import { ScrollProgress } from "@/components/magicui/scroll-progress";
import { Spotlight } from "@/components/ui/spotlight-new";

const dmSans = DM_Sans({
  variable: "--font-dm-sans",
  subsets: ["latin"],
});

const geist = Geist({
  variable: "--font-geist",
  subsets: ["latin"],
});

const geistMono = Geist_Mono({
  variable: "--font-geist-mono",
  subsets: ["latin"],
});

const plusJakartaSans = Plus_Jakarta_Sans({
  variable: "--font-plus-jakarta-sans",
  subsets: ["latin"],
});

export const metadata: Metadata = {
  title: "Collano",
  description:
    "Collano is your intelligent companion for the BNB Smart Chain ecosystem, revolutionizing how users interact with blockchain technology through natural language understanding and automated assistance.",
  openGraph: {
    type: "website",
    url: "https://ai-proj-10.vercel.app",
    title: "Collano",
    description:
      "Collano is your intelligent companion for the BNB Smart Chain ecosystem, revolutionizing how users interact with blockchain technology through natural language understanding and automated assistance.",
    images: `https://ai-proj-10.vercel.app/og-banner.png`,
  },
};

export default function RootLayout({
  children,
}: Readonly<{
  children: React.ReactNode;
}>) {
  return (
    <html lang="en">
      <body
        className={`${dmSans.variable} ${geist.className} ${geist.variable} ${geistMono.variable} ${plusJakartaSans.variable} antialiased min-h-[100svh] bg-[#063A19] overflow-x-hidden`}
      >
        <div className="relative z-10">{children}</div>

        <ScrollProgress />
        <Spotlight />
      </body>
    </html>
  );
}
