"use client";
import { useState } from "react";
import Link from "next/link";
import Image from "next/image";
import logoImg from "@/assets/images/brand/logo.png";
import iconImg from "@/assets/images/brand/icon.png";
import { motion } from "motion/react";

export default function Sidebar() {
  const [isActive, setIsActive] = useState<boolean>(true);

  return (
    <div
      className={`${
        isActive ? "w-[340px]" : "w-[110px]"
      } flex flex-col justify-between overflow-hidden duration-300`}
    >
      {isActive ? (
        <>
          <div className="min-w-[340px] p-7">
            <motion.div
              initial={{ y: -25, opacity: 0 }}
              whileInView={{ y: 0, opacity: 1 }}
              viewport={{ once: true }}
              transition={{ duration: 0.25 }}
              className="w-full flex justify-between items-center"
            >
              <Link href={"/"} className="flex items-center gap-2.5">
                <Image src={logoImg} alt="" width={160} />

                <p className="px-1.5 bg-[#D1CA0D] rounded-lg font-mono font-medium uppercase text-[#193818]">
                  Beta
                </p>
              </Link>

              <button
                onClick={() => {
                  setIsActive(false);
                }}
                className="flex"
              >
                <svg
                  viewBox="0 0 30 30"
                  fill="none"
                  xmlns="http://www.w3.org/2000/svg"
                  className="w-[28px] h-[28px]"
                >
                  <defs>
                    <clipPath id="clip1382_20239">
                      <rect
                        id="折叠边栏0730"
                        width="30.000000"
                        height="30.000000"
                        fill="white"
                        fillOpacity="0"
                      ></rect>
                    </clipPath>
                  </defs>
                  <rect
                    id="折叠边栏0730"
                    width="30.000000"
                    height="30.000000"
                    fill="#FFFFFF"
                    fillOpacity="0"
                  ></rect>
                  <g clipPath="url(#clip1382_20239)">
                    <rect
                      id="rect"
                      x="17.420410"
                      y="12.316406"
                      rx="1.000947"
                      width="5.995172"
                      height="2.001895"
                      transform="rotate(137.159 17.420410 12.316406)"
                      fill="#fff"
                      fillOpacity="1.000000"
                    ></rect>
                    <rect
                      id="rect"
                      x="12.959473"
                      y="13.728516"
                      rx="0.995190"
                      width="6.002943"
                      height="1.990380"
                      transform="rotate(40.853 12.959473 13.728516)"
                      fill="#fff"
                      fillOpacity="1.000000"
                    ></rect>
                    <path
                      id="path"
                      d="M20.1 25.5L9.9 25.51C9.48 25.51 9.06 25.47 8.65 25.39C8.24 25.3 7.84 25.18 7.45 25.02C7.06 24.86 6.69 24.66 6.34 24.43C5.99 24.19 5.67 23.92 5.37 23.63C5.07 23.33 4.81 23 4.58 22.65C4.34 22.3 4.15 21.93 3.98 21.54C3.82 21.15 3.7 20.75 3.62 20.34C3.54 19.93 3.5 19.51 3.5 19.09L3.5 10.93C3.5 10.51 3.54 10.1 3.62 9.68C3.7 9.27 3.82 8.87 3.98 8.48C4.15 8.09 4.34 7.72 4.58 7.37C4.81 7.02 5.07 6.69 5.37 6.39C5.67 6.1 5.99 5.83 6.34 5.6C6.69 5.36 7.06 5.16 7.45 5C7.84 4.84 8.24 4.72 8.65 4.64C9.06 4.55 9.48 4.51 9.9 4.51L20.1 4.5C20.52 4.5 20.94 4.54 21.35 4.62C21.76 4.7 22.16 4.83 22.55 4.99C22.94 5.15 23.31 5.35 23.66 5.58C24 5.82 24.33 6.08 24.62 6.38C24.92 6.68 25.19 7 25.42 7.35C25.65 7.7 25.85 8.07 26.01 8.46C26.17 8.85 26.3 9.25 26.38 9.67C26.46 10.08 26.5 10.5 26.5 10.92L26.5 19.07C26.5 19.5 26.46 19.91 26.38 20.32C26.3 20.74 26.17 21.14 26.01 21.53C25.85 21.92 25.65 22.29 25.42 22.64C25.19 22.99 24.92 23.31 24.62 23.61C24.33 23.91 24 24.17 23.66 24.41C23.31 24.64 22.94 24.84 22.55 25C22.16 25.16 21.76 25.29 21.35 25.37C20.94 25.45 20.52 25.5 20.1 25.5ZM9.9 6.6C9.61 6.6 9.33 6.63 9.05 6.69C8.78 6.74 8.51 6.82 8.24 6.93C7.98 7.04 7.73 7.18 7.5 7.33C7.26 7.49 7.04 7.67 6.84 7.87C6.64 8.07 6.46 8.29 6.31 8.53C6.15 8.77 6.02 9.01 5.91 9.28C5.8 9.54 5.72 9.81 5.66 10.09C5.61 10.37 5.58 10.65 5.58 10.93L5.58 19.09C5.58 19.37 5.61 19.65 5.66 19.93C5.72 20.21 5.8 20.48 5.91 20.74C6.02 21.01 6.15 21.26 6.31 21.49C6.46 21.73 6.64 21.95 6.84 22.15C7.04 22.35 7.26 22.53 7.5 22.69C7.73 22.85 7.98 22.98 8.24 23.09C8.51 23.2 8.78 23.28 9.05 23.33C9.33 23.39 9.61 23.42 9.9 23.42L20.1 23.41C20.38 23.41 20.67 23.37 20.94 23.32C21.22 23.26 21.49 23.18 21.75 23.07C22.01 22.96 22.26 22.83 22.5 22.67C22.73 22.51 22.95 22.33 23.15 22.13C23.35 21.93 23.53 21.71 23.69 21.48C23.85 21.24 23.98 20.99 24.09 20.73C24.2 20.47 24.28 20.2 24.33 19.92C24.39 19.64 24.42 19.36 24.42 19.07L24.42 10.92C24.42 10.64 24.39 10.35 24.33 10.07C24.28 9.79 24.2 9.52 24.09 9.26C23.98 9 23.85 8.75 23.69 8.51C23.53 8.28 23.35 8.06 23.15 7.86C22.95 7.66 22.73 7.48 22.5 7.32C22.26 7.16 22.01 7.03 21.75 6.92C21.49 6.81 21.22 6.73 20.94 6.67C20.67 6.62 20.38 6.59 20.1 6.59L9.9 6.6Z"
                      fill="#fff"
                      fillOpacity="1.000000"
                      fillRule="nonzero"
                    ></path>
                    <path
                      id="rect"
                      d="M8.5 5.51L10.54 5.51L10.6 24.43L8.55 24.43L8.5 5.51Z"
                      fill="#fff"
                      fillOpacity="1.000000"
                      fillRule="evenodd"
                    ></path>
                  </g>
                </svg>
              </button>
            </motion.div>

            <div className="my-5 w-full h-px bg-[#6B6700]"></div>

            <motion.p
              initial={{ y: -25, opacity: 0 }}
              whileInView={{ y: 0, opacity: 1 }}
              viewport={{ once: true }}
              transition={{ duration: 0.25, delay: 0.2 }}
              className="mb-2 font-mono text-sm font-medium uppercase text-[#D1CA0D]"
            >
              Your Conversations
            </motion.p>

            <motion.div
              initial={{ y: -25, opacity: 0 }}
              whileInView={{ y: 0, opacity: 1 }}
              viewport={{ once: true }}
              transition={{ duration: 0.25, delay: 0.4 }}
              className="w-full space-y-1.5"
            >
              <Link
                href={"/"}
                className="w-full py-2 px-4 bg-white/5 rounded-lg flex text-sm text-white duration-200"
              >
                Getting Started with...
              </Link>

              <Link
                href={"/"}
                className="w-full py-2 px-4 hover:bg-white/5 rounded-lg flex text-sm text-white/75 duration-200"
              >
                Lorem Ipsum..
              </Link>

              <Link
                href={"/"}
                className="w-full py-2 px-4 hover:bg-white/5 rounded-lg flex text-sm text-white/75 duration-200"
              >
                Duis aute irure...
              </Link>

              <Link
                href={"/"}
                className="w-full py-2 px-4 hover:bg-white/5 rounded-lg flex text-sm text-white/75 duration-200"
              >
                Dolor in reprehenderit...
              </Link>

              <Link
                href={"/"}
                className="w-full py-2 px-4 hover:bg-white/5 rounded-lg flex text-sm text-white/75 duration-200"
              >
                Excepteur sint...
              </Link>

              <Link
                href={"/"}
                className="w-full py-2 px-4 hover:bg-white/5 rounded-lg flex text-sm text-white/75 duration-200"
              >
                Ut enim ad minim...
              </Link>

              <Link
                href={"/"}
                className="w-full py-2 px-4 hover:bg-white/5 rounded-lg flex text-sm text-white/75 duration-200"
              >
                Lorem ipsum dolor...
              </Link>
            </motion.div>

            <motion.p
              initial={{ y: -25, opacity: 0 }}
              whileInView={{ y: 0, opacity: 1 }}
              viewport={{ once: true }}
              transition={{ duration: 0.25, delay: 0.6 }}
              className="mt-5 font-mono text-sm font-medium uppercase text-[#D1CA0D]"
            >
              Subscriptions{" "}
              <span className="py-1 px-2 border border-white/25 bg-white/10 rounded-md text-white">
                Coming Soon
              </span>
            </motion.p>
          </div>

          <motion.div
            initial={{ y: -25, opacity: 0 }}
            whileInView={{ y: 0, opacity: 1 }}
            viewport={{ once: true }}
            transition={{ duration: 0.25, delay: 0.8 }}
            className="min-w-[340px] p-7"
          >
            <div className="mb-2 py-2.5 px-4 border border-transparent hover:border-[#D1CA0D] bg-white/10 hover:shadow-[0px_0px_5px_4px_rgba(209,202,13,0.25),0px_0px_20px_5px_rgba(209,202,13,0.25)_inset] rounded-lg flex justify-between items-center duration-200">
              <p className="text-sm font-medium text-white">Mobile Version</p>

              <span className="py-1 px-2 border border-white/25 bg-white/10 rounded-md text-xs font-medium uppercase text-white">
                Coming Soon
              </span>
            </div>

            <div className="p-4 border border-transparent hover:border-[#D1CA0D] bg-white/10 hover:shadow-[0px_0px_5px_4px_rgba(209,202,13,0.25),0px_0px_20px_5px_rgba(209,202,13,0.25)_inset] rounded-lg flex justify-between items-center duration-200">
              <p className="flex items-center gap-3 font-medium text-white">
                <svg
                  width="27"
                  height="22"
                  viewBox="0 0 27 22"
                  fill="none"
                  xmlns="http://www.w3.org/2000/svg"
                >
                  <path
                    d="M7.25 14.75V7.25"
                    stroke="white"
                    strokeWidth="1.875"
                    strokeLinecap="round"
                    strokeLinejoin="round"
                  />
                  <path
                    d="M24.5416 7.25H21.2885C19.0581 7.25 17.25 8.92887 17.25 11C17.25 13.0711 19.0581 14.75 21.2885 14.75H24.5416C24.6459 14.75 24.6979 14.75 24.7419 14.7474C25.416 14.7063 25.9529 14.2078 25.9971 13.5818C26 13.5409 26 13.4925 26 13.3959V8.60412C26 8.5075 26 8.45907 25.9971 8.41825C25.9529 7.7923 25.416 7.2937 24.7419 7.25268C24.6979 7.25 24.6459 7.25 24.5416 7.25Z"
                    stroke="white"
                    strokeWidth="1.875"
                  />
                  <path
                    d="M24.7062 7.25C24.6091 4.90962 24.2957 3.47469 23.2855 2.46446C21.8211 1 19.464 1 14.75 1H11C6.28595 1 3.92894 1 2.46446 2.46446C1 3.92894 1 6.28595 1 11C1 15.714 1 18.0711 2.46446 19.5355C3.92894 21 6.28595 21 11 21H14.75C19.464 21 21.8211 21 23.2855 19.5355C24.2957 18.5254 24.6091 17.0904 24.7062 14.75"
                    stroke="white"
                    strokeWidth="1.875"
                  />
                  <path
                    d="M20.9888 11H21.0003"
                    stroke="white"
                    strokeWidth="2.5"
                    strokeLinecap="round"
                    strokeLinejoin="round"
                  />
                </svg>{" "}
                0x..........abcd
              </p>

              <div className="group relative">
                <button className="flex">
                  <svg
                    width="24"
                    height="24"
                    viewBox="0 0 24 24"
                    fill="none"
                    xmlns="http://www.w3.org/2000/svg"
                  >
                    <path
                      d="M16.3083 4.38394C15.7173 4.38394 15.4217 4.38394 15.1525 4.28405C15.1151 4.27017 15.0783 4.25491 15.042 4.23828C14.781 4.11855 14.5721 3.90959 14.1541 3.49167C13.1922 2.52977 12.7113 2.04882 12.1195 2.00447C12.04 1.99851 11.96 1.99851 11.8805 2.00447C11.2887 2.04882 10.8077 2.52977 9.84585 3.49166C9.42793 3.90959 9.21897 4.11855 8.95797 4.23828C8.92172 4.25491 8.88486 4.27017 8.84747 4.28405C8.57825 4.38394 8.28273 4.38394 7.69171 4.38394H7.58269C6.07478 4.38394 5.32083 4.38394 4.85239 4.85239C4.38394 5.32083 4.38394 6.07478 4.38394 7.58269V7.69171C4.38394 8.28273 4.38394 8.57825 4.28405 8.84747C4.27017 8.88486 4.25491 8.92172 4.23828 8.95797C4.11855 9.21897 3.90959 9.42793 3.49166 9.84585C2.52977 10.8077 2.04882 11.2887 2.00447 11.8805C1.99851 11.96 1.99851 12.04 2.00447 12.1195C2.04882 12.7113 2.52977 13.1922 3.49166 14.1541C3.90959 14.5721 4.11855 14.781 4.23828 15.042C4.25491 15.0783 4.27017 15.1151 4.28405 15.1525C4.38394 15.4217 4.38394 15.7173 4.38394 16.3083V16.4173C4.38394 17.9252 4.38394 18.6792 4.85239 19.1476C5.32083 19.6161 6.07478 19.6161 7.58269 19.6161H7.69171C8.28273 19.6161 8.57825 19.6161 8.84747 19.716C8.88486 19.7298 8.92172 19.7451 8.95797 19.7617C9.21897 19.8815 9.42793 20.0904 9.84585 20.5083C10.8077 21.4702 11.2887 21.9512 11.8805 21.9955C11.96 22.0015 12.0399 22.0015 12.1195 21.9955C12.7113 21.9512 13.1922 21.4702 14.1541 20.5083C14.5721 20.0904 14.781 19.8815 15.042 19.7617C15.0783 19.7451 15.1151 19.7298 15.1525 19.716C15.4217 19.6161 15.7173 19.6161 16.3083 19.6161H16.4173C17.9252 19.6161 18.6792 19.6161 19.1476 19.1476C19.6161 18.6792 19.6161 17.9252 19.6161 16.4173V16.3083C19.6161 15.7173 19.6161 15.4217 19.716 15.1525C19.7298 15.1151 19.7451 15.0783 19.7617 15.042C19.8815 14.781 20.0904 14.5721 20.5083 14.1541C21.4702 13.1922 21.9512 12.7113 21.9955 12.1195C22.0015 12.0399 22.0015 11.96 21.9955 11.8805C21.9512 11.2887 21.4702 10.8077 20.5083 9.84585C20.0904 9.42793 19.8815 9.21897 19.7617 8.95797C19.7451 8.92172 19.7298 8.88486 19.716 8.84747C19.6161 8.57825 19.6161 8.28273 19.6161 7.69171V7.58269C19.6161 6.07478 19.6161 5.32083 19.1476 4.85239C18.6792 4.38394 17.9252 4.38394 16.4173 4.38394H16.3083Z"
                      stroke="white"
                      strokeWidth="1.5"
                    />
                    <path
                      d="M15.5 12C15.5 13.933 13.933 15.5 12 15.5C10.067 15.5 8.5 13.933 8.5 12C8.5 10.067 10.067 8.5 12 8.5C13.933 8.5 15.5 10.067 15.5 12Z"
                      stroke="white"
                      strokeWidth="1.5"
                    />
                  </svg>
                </button>

                <div className="absolute bottom-full right-0 pb-2 opacity-0 group-focus-within:opacity-100 pointer-events-none group-focus-within:pointer-events-auto duration-200">
                  <Link
                    href={"/"}
                    className="py-1.5 px-2 border border-white/10 bg-white/10 backdrop-blur-3xl rounded-md flex items-center gap-2 text-sm whitespace-nowrap text-white"
                  >
                    <svg
                      width="16"
                      height="16"
                      viewBox="0 0 16 16"
                      fill="none"
                      xmlns="http://www.w3.org/2000/svg"
                      className="w-[16px] min-w-[16px]"
                    >
                      <path
                        d="M9.33333 2.06335C9.02867 2.02161 8.717 2 8.4 2C4.86538 2 2 4.68629 2 8C2 11.3137 4.86538 14 8.4 14C8.717 14 9.02867 13.9784 9.33333 13.9367"
                        stroke="#E7400C"
                        strokeLinecap="round"
                      />
                      <path
                        d="M14.0002 8.00004H7.3335M14.0002 8.00004C14.0002 7.53324 12.6706 6.66106 12.3335 6.33337M14.0002 8.00004C14.0002 8.46684 12.6706 9.33904 12.3335 9.66671"
                        stroke="#E7400C"
                        strokeLinecap="round"
                        strokeLinejoin="round"
                      />
                    </svg>
                    Log out
                  </Link>
                </div>
              </div>
            </div>

            <div className="mt-3.5 mb-5 w-full h-px bg-white/10"></div>

            <div className="flex justify-between items-center">
              <p className="text-white/75">© 2025 Collano Labs</p>

              <div className="flex items-center gap-4">
                <Link href={"/"} className="group flex">
                  <svg
                    width="20"
                    height="20"
                    viewBox="0 0 20 20"
                    fill="none"
                    xmlns="http://www.w3.org/2000/svg"
                  >
                    <path
                      d="M15.2719 1.58661H18.0831L11.9414 8.60619L19.1666 18.1582H13.5093L9.07834 12.365L4.00827 18.1582H1.19534L7.76451 10.65L0.833313 1.58661H6.63424L10.6395 6.88189L15.2719 1.58661ZM14.2852 16.4756H15.843L5.78781 3.18089H4.1162L14.2852 16.4756Z"
                      fill="white"
                      className="group-hover:fill-[#d1ca0d] duration-200"
                    />
                  </svg>
                </Link>

                <Link href={"/"} className="group flex">
                  <svg
                    width="20"
                    height="20"
                    viewBox="0 0 20 20"
                    fill="none"
                    xmlns="http://www.w3.org/2000/svg"
                  >
                    <path
                      d="M8.42967 10.5292C9.39247 11.0849 9.87385 11.3627 10.4026 11.3632C10.9312 11.3636 11.4131 11.0866 12.3769 10.5326L18.5204 7.00114C18.7978 6.84173 18.9687 6.54622 18.9687 6.22631C18.9687 5.9064 18.7978 5.6109 18.5204 5.45148L12.3747 1.91871C11.4119 1.3653 10.9306 1.0886 10.4024 1.08881C9.87422 1.08901 9.39308 1.36609 8.43078 1.92025L3.14748 4.96274C3.10831 4.9853 3.08875 4.99656 3.07049 5.00723C1.26576 6.06373 0.150741 7.99253 0.135832 10.0837C0.135681 10.1048 0.135681 10.1274 0.135681 10.1726C0.135681 10.2178 0.135681 10.2403 0.135832 10.2614C0.150708 12.3502 1.26324 14.2772 3.06475 15.3346C3.08296 15.3453 3.1025 15.3565 3.14161 15.3791L6.45105 17.2899C8.37945 18.4033 9.34364 18.96 10.4025 18.9603C11.4613 18.9607 12.4259 18.4046 14.3551 17.2926L17.8486 15.2786C18.8146 14.7217 19.2976 14.4433 19.5628 13.9843C19.828 13.5253 19.828 12.9678 19.828 11.8528V9.69893C19.828 9.3896 19.6605 9.10456 19.3902 8.95403C19.1287 8.8084 18.81 8.81056 18.5505 8.95973L11.3869 13.0776C10.9063 13.3539 10.6659 13.492 10.4022 13.4921C10.1385 13.4922 9.89813 13.3542 9.41733 13.0782L4.56884 10.295C4.32598 10.1556 4.20453 10.0859 4.10699 10.0733C3.88462 10.0446 3.67081 10.1692 3.5861 10.3768C3.54896 10.4679 3.5497 10.6079 3.55121 10.8879C3.55231 11.0941 3.55287 11.1972 3.57213 11.292C3.6153 11.5043 3.72699 11.6966 3.8901 11.8392C3.96293 11.9029 4.05219 11.9544 4.23075 12.0575L9.41459 15.0494C9.89665 15.3276 10.1377 15.4667 10.4023 15.4668C10.667 15.4669 10.9081 15.3279 11.3903 15.0499L17.7441 11.3873C17.9088 11.2924 17.9912 11.2449 18.053 11.2806C18.1147 11.3163 18.1147 11.4113 18.1147 11.6014V12.5784C18.1147 12.8572 18.1147 12.9965 18.0484 13.1113C17.9821 13.226 17.8613 13.2957 17.6198 13.4349L12.3791 16.4558C11.4143 17.0119 10.9319 17.29 10.4024 17.2898C9.8729 17.2895 9.39074 17.011 8.42647 16.454L3.52336 13.6217C3.50779 13.6126 3.50001 13.6082 3.49275 13.6039C2.46469 13.0032 1.83034 11.9042 1.82439 10.7134C1.82435 10.705 1.82435 10.6961 1.82435 10.6781V9.78126C1.82435 9.12394 2.17443 8.5164 2.74312 8.18677C3.24564 7.89548 3.86548 7.8949 4.36853 8.18526L8.42967 10.5292Z"
                      fill="white"
                      className="group-hover:fill-[#d1ca0d] duration-200"
                    />
                  </svg>
                </Link>
              </div>
            </div>
          </motion.div>
        </>
      ) : (
        <>
          <div className="min-w-[110px] p-10 pt-7 pl-7 flex flex-col items-center">
            <Link href={"/"} className="flex items-center gap-2.5">
              <Image src={iconImg} alt="" height={35} />
            </Link>

            <button
              onClick={() => {
                setIsActive(true);
              }}
              className="rotate-[180deg] mt-5 flex"
            >
              <svg
                viewBox="0 0 30 30"
                fill="none"
                xmlns="http://www.w3.org/2000/svg"
                className="w-[28px] h-[28px]"
              >
                <defs>
                  <clipPath id="clip1382_20239">
                    <rect
                      id="折叠边栏0730"
                      width="30.000000"
                      height="30.000000"
                      fill="white"
                      fillOpacity="0"
                    ></rect>
                  </clipPath>
                </defs>
                <rect
                  id="折叠边栏0730"
                  width="30.000000"
                  height="30.000000"
                  fill="#FFFFFF"
                  fillOpacity="0"
                ></rect>
                <g clipPath="url(#clip1382_20239)">
                  <rect
                    id="rect"
                    x="17.420410"
                    y="12.316406"
                    rx="1.000947"
                    width="5.995172"
                    height="2.001895"
                    transform="rotate(137.159 17.420410 12.316406)"
                    fill="#fff"
                    fillOpacity="1.000000"
                  ></rect>
                  <rect
                    id="rect"
                    x="12.959473"
                    y="13.728516"
                    rx="0.995190"
                    width="6.002943"
                    height="1.990380"
                    transform="rotate(40.853 12.959473 13.728516)"
                    fill="#fff"
                    fillOpacity="1.000000"
                  ></rect>
                  <path
                    id="path"
                    d="M20.1 25.5L9.9 25.51C9.48 25.51 9.06 25.47 8.65 25.39C8.24 25.3 7.84 25.18 7.45 25.02C7.06 24.86 6.69 24.66 6.34 24.43C5.99 24.19 5.67 23.92 5.37 23.63C5.07 23.33 4.81 23 4.58 22.65C4.34 22.3 4.15 21.93 3.98 21.54C3.82 21.15 3.7 20.75 3.62 20.34C3.54 19.93 3.5 19.51 3.5 19.09L3.5 10.93C3.5 10.51 3.54 10.1 3.62 9.68C3.7 9.27 3.82 8.87 3.98 8.48C4.15 8.09 4.34 7.72 4.58 7.37C4.81 7.02 5.07 6.69 5.37 6.39C5.67 6.1 5.99 5.83 6.34 5.6C6.69 5.36 7.06 5.16 7.45 5C7.84 4.84 8.24 4.72 8.65 4.64C9.06 4.55 9.48 4.51 9.9 4.51L20.1 4.5C20.52 4.5 20.94 4.54 21.35 4.62C21.76 4.7 22.16 4.83 22.55 4.99C22.94 5.15 23.31 5.35 23.66 5.58C24 5.82 24.33 6.08 24.62 6.38C24.92 6.68 25.19 7 25.42 7.35C25.65 7.7 25.85 8.07 26.01 8.46C26.17 8.85 26.3 9.25 26.38 9.67C26.46 10.08 26.5 10.5 26.5 10.92L26.5 19.07C26.5 19.5 26.46 19.91 26.38 20.32C26.3 20.74 26.17 21.14 26.01 21.53C25.85 21.92 25.65 22.29 25.42 22.64C25.19 22.99 24.92 23.31 24.62 23.61C24.33 23.91 24 24.17 23.66 24.41C23.31 24.64 22.94 24.84 22.55 25C22.16 25.16 21.76 25.29 21.35 25.37C20.94 25.45 20.52 25.5 20.1 25.5ZM9.9 6.6C9.61 6.6 9.33 6.63 9.05 6.69C8.78 6.74 8.51 6.82 8.24 6.93C7.98 7.04 7.73 7.18 7.5 7.33C7.26 7.49 7.04 7.67 6.84 7.87C6.64 8.07 6.46 8.29 6.31 8.53C6.15 8.77 6.02 9.01 5.91 9.28C5.8 9.54 5.72 9.81 5.66 10.09C5.61 10.37 5.58 10.65 5.58 10.93L5.58 19.09C5.58 19.37 5.61 19.65 5.66 19.93C5.72 20.21 5.8 20.48 5.91 20.74C6.02 21.01 6.15 21.26 6.31 21.49C6.46 21.73 6.64 21.95 6.84 22.15C7.04 22.35 7.26 22.53 7.5 22.69C7.73 22.85 7.98 22.98 8.24 23.09C8.51 23.2 8.78 23.28 9.05 23.33C9.33 23.39 9.61 23.42 9.9 23.42L20.1 23.41C20.38 23.41 20.67 23.37 20.94 23.32C21.22 23.26 21.49 23.18 21.75 23.07C22.01 22.96 22.26 22.83 22.5 22.67C22.73 22.51 22.95 22.33 23.15 22.13C23.35 21.93 23.53 21.71 23.69 21.48C23.85 21.24 23.98 20.99 24.09 20.73C24.2 20.47 24.28 20.2 24.33 19.92C24.39 19.64 24.42 19.36 24.42 19.07L24.42 10.92C24.42 10.64 24.39 10.35 24.33 10.07C24.28 9.79 24.2 9.52 24.09 9.26C23.98 9 23.85 8.75 23.69 8.51C23.53 8.28 23.35 8.06 23.15 7.86C22.95 7.66 22.73 7.48 22.5 7.32C22.26 7.16 22.01 7.03 21.75 6.92C21.49 6.81 21.22 6.73 20.94 6.67C20.67 6.62 20.38 6.59 20.1 6.59L9.9 6.6Z"
                    fill="#fff"
                    fillOpacity="1.000000"
                    fillRule="nonzero"
                  ></path>
                  <path
                    id="rect"
                    d="M8.5 5.51L10.54 5.51L10.6 24.43L8.55 24.43L8.5 5.51Z"
                    fill="#fff"
                    fillOpacity="1.000000"
                    fillRule="evenodd"
                  ></path>
                </g>
              </svg>
            </button>
          </div>

          <div className="min-w-[110px] p-10 pb-7 pl-7">
            <div className="p-2 border border-transparent hover:border-[#D1CA0D] bg-white/10 hover:shadow-[0px_0px_5px_4px_rgba(209,202,13,0.25),0px_0px_20px_5px_rgba(209,202,13,0.25)_inset] rounded-lg flex justify-center items-center duration-200">
              <svg
                width="24"
                height="22"
                viewBox="0 0 27 22"
                fill="none"
                xmlns="http://www.w3.org/2000/svg"
              >
                <path
                  d="M7.25 14.75V7.25"
                  stroke="white"
                  strokeWidth="1.875"
                  strokeLinecap="round"
                  strokeLinejoin="round"
                />
                <path
                  d="M24.5416 7.25H21.2885C19.0581 7.25 17.25 8.92887 17.25 11C17.25 13.0711 19.0581 14.75 21.2885 14.75H24.5416C24.6459 14.75 24.6979 14.75 24.7419 14.7474C25.416 14.7063 25.9529 14.2078 25.9971 13.5818C26 13.5409 26 13.4925 26 13.3959V8.60412C26 8.5075 26 8.45907 25.9971 8.41825C25.9529 7.7923 25.416 7.2937 24.7419 7.25268C24.6979 7.25 24.6459 7.25 24.5416 7.25Z"
                  stroke="white"
                  strokeWidth="1.875"
                />
                <path
                  d="M24.7062 7.25C24.6091 4.90962 24.2957 3.47469 23.2855 2.46446C21.8211 1 19.464 1 14.75 1H11C6.28595 1 3.92894 1 2.46446 2.46446C1 3.92894 1 6.28595 1 11C1 15.714 1 18.0711 2.46446 19.5355C3.92894 21 6.28595 21 11 21H14.75C19.464 21 21.8211 21 23.2855 19.5355C24.2957 18.5254 24.6091 17.0904 24.7062 14.75"
                  stroke="white"
                  strokeWidth="1.875"
                />
                <path
                  d="M20.9888 11H21.0003"
                  stroke="white"
                  strokeWidth="2.5"
                  strokeLinecap="round"
                  strokeLinejoin="round"
                />
              </svg>
            </div>
          </div>
        </>
      )}
    </div>
  );
}
